aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gdb/ChangeLog4
-rw-r--r--gdb/xcoffread.c13
2 files changed, 10 insertions, 7 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 94eaa73..b309561 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,7 @@
+Thu Sep 29 08:22:27 1994 Jim Kingdon (kingdon@lioth.cygnus.com)
+
+ * xcoffread.c (read_xcoff_symtab): Fix comment for yesterday's change.
+
Wed Sep 28 17:48:18 1994 Jim Kingdon (kingdon@lioth.cygnus.com)
* coffread.c (complete_symtab): If last_source_file is set upon
diff --git a/gdb/xcoffread.c b/gdb/xcoffread.c
index 70f501d..5605131 100644
--- a/gdb/xcoffread.c
+++ b/gdb/xcoffread.c
@@ -1405,13 +1405,12 @@ read_xcoff_symtab (objfile, nsyms)
continue;
default:
- /* xlc and old versions of gcc put each variable in a
- separate csect, so we get an XTY_SD. But new (2.5?
- 2.6? something like that) gcc's put several variables
- in a csect, so that each variable only gets an XTY_LD.
- We still need to record them. This will typically be
- XMC_RW; I suspect XMC_RO and XMC_BS might be possible
- too. */
+ /* xlc puts each variable in a separate csect, so we get
+ an XTY_SD for each variable. But gcc puts several
+ variables in a csect, so that each variable only gets
+ an XTY_LD. We still need to record them. This will
+ typically be XMC_RW; I suspect XMC_RO and XMC_BS might
+ be possible too. */
break;
}